@@ -1,43 +1,48 @@
 import os
 import sys
+import time
+from typing import Optional
 
-from . import (copy, getPath, makeFolder, makeTempWorkspace, readFile,
-               remove, writeFile)
+import typer
+
+from . import (copy, getPath, makeFolder, makeTempWorkspace, readFile, remove,
+               writeFile)
 from .byte import decode
-from .zip import zipFileExtract
 from .execute import execute
+from .zip import zipFileExtract
+
+app = typer.Typer()
 
 
 def main():
-    parList = sys.argv[1:]
-    if parList:
-        funcName = parList.pop(0)
-        if funcName not in funcNameList:
-            exit(f"非法命令名称 {funcName}", True)
-        func = eval(funcName)
-        func(*parList)
-    else:
-        # 没有输入命令
-        exit("", True)
+    app()
 
 
-helpInfo = '''
+# @app.command(
+#     help="help",
+#     short_help="short_help",
+# )
+# def test(
+#     par1: str,
+#     par2: str = "par2",
+#     par3: Optional[str] = typer.Argument("par3", help="这是参数描述", show_default=False),
+#     par4: Optional[str] = typer.Argument("par4", help="这是参数描述"),
+# ):
+#     print(par1, par2, par3, par4)
 
-beniutils task_create <target_path>
-创建beniutils.task项目（如果不传入目标路径则在当前系统路径下进行）
+def exit(errorMsg: str):
+    print(errorMsg)
+    sys.exit(errorMsg and 1 or 0)
 
-beniutils task_build <target_path>
-发布beniutils.task项目（如果不传入目标路径则在当前系统路径下进行）
-
-'''
-
-funcNameList = [
-    "task_create",
-    "task_build",
-]
+# ------------------------------------------------------------------------
 
 
-def task_create(targetPath: str = ""):
+@app.command(
+    help="创建 beniutils.task 项目",
+)
+def task_create(
+    targetPath: Optional[str] = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
+):
     targetPath = targetPath or os.getcwd()
     makeFolder(targetPath)
     workspaceFolder = makeTempWorkspace()
@@ -57,7 +62,12 @@ def task_create(targetPath: str = ""):
         remove(workspaceFolder)
 
 
-def task_build(targetPath: str = ""):
+@app.command(
+    help="发布 beniutils.task 项目",
+)
+def task_build(
+    targetPath: Optional[str] = typer.Argument("", help="指定项目路径，默认在当前系统路径", show_default=False),
+):
     currentPath: str = ""
     workspaceFolder: str = ""
     try:
@@ -112,9 +122,18 @@ def task_build(targetPath: str = ""):
             remove(workspaceFolder)
 
 
-def exit(errorMsg: str, isShowHelpInfo: bool = False):
-    if errorMsg:
-        print(errorMsg)
-    if isShowHelpInfo:
-        print(helpInfo)
-    sys.exit(errorMsg and 1 or 0)
+@app.command(
+    help="格式化时间戳",
+)
+def timestamp(
+    value: Optional[float] = typer.Argument(None, help="时间戳，默认使用当前系统的时间戳", show_default=False),
+):
+    value = value or time.time()
+    print()
+    localtime = time.localtime(value)
+    tzname = time.tzname[(time.daylight and localtime.tm_isdst) and 1 or 0]
+    print(value)
+    print()
+    print(tzname)
+    print(time.strftime("%Y-%m-%d %H:%M:%S", localtime))
+    print()
